.. _bluegraph_backends_ref:

`bluegraph.backends` package
------------------------------

.. toctree::
   :hidden:

   ../packages/bluegraph_backends_networkx
   ../packages/bluegraph_backends_graph_tool
   ../packages/bluegraph_backends_neo4j
   ../packages/bluegraph_backends_stellargraph
